@@ -22,6 +22,7 @@ void Settings::restoreSettings() {
     setXTubeEnabled(value("enableXTube", false).toBool());
     setXTubeQuality(value("xtubeQuality", QString("mobile")).toString());
     setUploadAttribute(value("uploadAttribute", tr("Uploaded via cuteTube")).toString());
+    setShowRelatedVideos(value("showRelatedVideos", true).toBool());
     endGroup();
 
     beginGroup("Transfers");
@@ -45,6 +46,7 @@ void Settings::restoreSettings() {
 
     beginGroup("System");
     setOrientation(value("screenOrientation", QString("auto")).toString());
+    setMaximumFlickVelocity(value("maximumFlickVelocity", 2000).toInt());
     endGroup();
 
     beginGroup("Accounts");
@@ -66,6 +68,7 @@ void Settings::saveSettings() {
     setValue("enableXTube", xtubeEnabled);
     setValue("xtubeQuality", xtubeQuality);
     setValue("uploadAttribute", uploadAttribute);
+    setValue("showRelatedVideos", showRelatedVideos);
     endGroup();
 
     beginGroup("Transfers");
@@ -92,6 +95,7 @@ void Settings::saveSettings() {
 
     beginGroup("System");
     setValue("screenOrientation", screenOrientation);
+    setValue("maximumFlickVelocity", maximumFlickVelocity);
     endGroup();
 
     beginGroup("Accounts");
@@ -116,6 +120,11 @@ void Settings::setUploadAttribute(const QString &attribute) {
     emit uploadAttributeChanged();
 }
 
+void Settings::setShowRelatedVideos(bool show) {
+    showRelatedVideos = show;
+    emit showRelatedVideosChanged();
+}
+
 void Settings::setYouTubeDownloadQuality(const QString &quality) {
     youtubeDownloadQuality = quality;
     emit youtubeDownloadQualityChanged(quality);
@@ -214,6 +223,11 @@ void Settings::setOrientation(const QString &orientation) {
     emit orientationChanged(orientation);
 }
 
+void Settings::setMaximumFlickVelocity(int velocity) {
+    maximumFlickVelocity = velocity;
+    emit maximumFlickVelocityChanged();
+}
+
 void Settings::setNetworkProxy(const QString &proxy) {
     networkProxy = proxy;
     emit networkProxyChanged(proxy);
